<?php

	/*
	 * Trecho de insert de produtos na tabela loja_servicos
	 *
	 */

	require 'auxiliares/funcao-slug.php';

	$caminhoAmigavel = slug($_POST['nomeProduto']);

	$selectSlug = mysql_query("SELECT * FROM loja_servico WHERE slugProduto = '".mysql_escape_string($caminhoAmigavel)."' AND categoria = '".mysql_escape_string($_POST['categoriaProduto'])."'");

	$qtSlugs = mysql_num_rows($selectSlug);

	if($qtSlugs > 0) $caminhoAmigavel .= "-".$qtSlugs;

	// resolver fabricante
	if ($_POST['novoFabricante'] == 1) {
		
		$insertFabricante = mysql_query("INSERT INTO loja_fabricante (titulo, siteFabricante) VALUES ('".mysql_escape_string(utf8_decode($_POST['novoTextFabricante']))."', '".mysql_escape_string(utf8_decode($_POST['siteTextFabricante']))."')");
		// echo "INSERT INTO loja_fabricante (titulo, siteFabricante) VALUES ('".utf8_decode($_POST['novoTextFabricante'])."', '".$_POST['siteTextFabricante']."')";
		$idFabricante = mysql_insert_id();
	}
	else {

		$idFabricante = $_POST['selectFabricante'];
	}

	include_once("auxiliares/redimensionaImg.class.php");

	$redim = new Redimensiona();

	// resolver fotos
	if ($_FILES['fotoPrincipalProduto']['size'] > 0) {
		
		$numero = rand(1,99999999);
		$nome = $numero.$_FILES['fotoPrincipalProduto']['name'];
		$nome = $redim->tratar_arquivo_upload($nome);
		
		$tipoImagem = $_FILES['fotoPrincipalProduto']['type'];

		// Thumbs
		$fotoThumbs = $_FILES['fotoPrincipalProduto']['tmp_name'];	
		$filenameThumbs = $redim->GerarThumbs($fotoThumbs, 65, 65, "imagens-site/loja/thumbs", $tipoImagem, $nome);

		// Capa
		$fotoThumbs = $_FILES['fotoPrincipalProduto']['tmp_name'];	
		$filenameThumbs = $redim->Redimensionar($fotoThumbs, 284, 123, "imagens-site/loja/capas", $tipoImagem, $nome);

		// Medium
		$fotoThumbs = $_FILES['fotoPrincipalProduto']['tmp_name'];	
		$filenameThumbs = $redim->Redimensionar($fotoThumbs, 230, 230, "imagens-site/loja/medium", $tipoImagem, $nome);

		// Normal
		$foto = $_FILES['fotoPrincipalProduto']['tmp_name'];	
		$filenameDestaque = $redim->Redimensionar($foto, 1000, 1000, "imagens-site/loja", $tipoImagem, $nome);

	}

	$insertProduto = mysql_query("INSERT INTO loja_servico (categoria, fabricante, titulo, textoApresentacao, descricao, especificacoes, fotoDestaque, estoque, preco_custo, preco_venda, peso, altura, largura, comprimento, destaque, oferta, slugProduto, keywords) VALUES ('".mysql_escape_string($_POST['categoriaProduto'])."', '".mysql_escape_string($idFabricante)."', '".mysql_escape_string(utf8_decode($_POST['nomeProduto']))."', '".mysql_escape_string(utf8_decode($_POST['textoApresentacao']))."', '".mysql_escape_string(utf8_decode($_POST['descricao']))."', '".mysql_escape_string(utf8_decode($_POST['especificacoes']))."', '".mysql_escape_string($filenameDestaque)."', '".mysql_escape_string($_POST['estoqueProduto'])."', '".str_replace(",", ".", mysql_escape_string($_POST['precoCustoProduto']))."', '".str_replace(",", ".", mysql_escape_string($_POST['precoVendaProduto']))."', '".str_replace(",", ".", mysql_escape_string($_POST['pesoProduto']))."', '".str_replace(",", ".", mysql_escape_string($_POST['alturaProduto']))."', '".str_replace(",", ".", mysql_escape_string($_POST['larguraProduto']))."', '".str_replace(",", ".", mysql_escape_string($_POST['comprimentoProduto']))."', '".mysql_escape_string($_POST['chkProdutoDestaque'])."', '".mysql_escape_string($_POST['chkProdutoOferta'])."', '".mysql_escape_string($caminhoAmigavel)."', '".mysql_escape_string(utf8_decode(implode(",", $_POST['keywords'])))."')");

	// Retorna o id do último insert ($insertProduto)
	$idProduto = mysql_insert_id();
	/*
	 * Fim trecho de insert de produtos na tabela produtos
	 *
	 * Trecho de insert de imagens de produtos na tabela loja_gallery_serv
	 * obs.: a imagem de destaque não esta incluída nessa tabela, mas sim junto com a descrição de produtos na tabela loja_servicos
	 */

	if ($insertProduto) {
	
		$arrayImagens = array();

		for ($i=0; $i < count($_FILES['fotoGaleriaProduto']['name']); $i++) { 
			
			if ($_FILES['fotoGaleriaProduto']['size'][$i] > 0) {

				$numero = rand(1,99999999);
				$nome = $numero.$_FILES['fotoGaleriaProduto']['name'][$i];
				$nome = $redim->tratar_arquivo_upload($nome);
				
				$tipoImagem = $_FILES['fotoGaleriaProduto']['type'][$i];

				// Thumbs
				$fotoThumbs = $_FILES['fotoGaleriaProduto']['tmp_name'][$i];	
				$filenameGallery = $redim->GerarThumbs($fotoThumbs, 65, 65, "imagens-site/loja/thumbs", $tipoImagem, $nome);

				// Medium
				$foto = $_FILES['fotoGaleriaProduto']['tmp_name'][$i];	
				$filenameGallery = $redim->Redimensionar($foto, 230, 230, "imagens-site/loja/medium", $tipoImagem, $nome);

				// Normal
				$foto = $_FILES['fotoGaleriaProduto']['tmp_name'][$i];	
				$filenameGallery = $redim->Redimensionar($foto, 1000, 1000, "imagens-site/loja", $tipoImagem, $nome);

				if(!empty($filenameGallery)) $arrayImagens[] = "('".mysql_escape_string($idProduto)."', '".mysql_escape_string($filenameGallery)."')";

			}

			
		}

		$imagensGalleryDb = implode(",", $arrayImagens);

		$insertFotosGallery = mysql_query("INSERT INTO loja_gallery_serv (idProduto, imagem) VALUES $imagensGalleryDb");

		// $arrUnProdutos = array_unique($_POST['arrSelProduto']);

		// $arrProdutos = array(); 

		// foreach ($arrUnProdutos as $key => $value) {
		// 	if($value > 0) $arrProdutos[] = "('".mysql_escape_string($idProduto)."','".mysql_escape_string($value)."')";
		// }


		// if(count($arrProdutos) > 0){

		// 	// print_r($arrProdutos);

		// 	$queryInsertProdServico = " INSERT INTO loja_prod_serv (id_servico, id_produto) 
		// 								VALUES ".implode(",", $arrProdutos);

		// 	$insertProdServico = mysql_query($queryInsertProdServico);
		// }
	}

	if ($insertProduto || $insertFotosGallery) {

		echo "Inserido";
	}

	if (!$insertProduto && !$insertFotosGallery) {
		echo "Ocorreu um erro ao cadastrar o produto. Para suporte, use nosso chat &agrave; sua direita";
	}

?>